@@ -4,23 +4,37 @@ import os
 
 
 if not DEV:
-    from .db import delete, draw,fetch,drop,update_data,insert_data,change_db
+    from .db import delete, draw,fetch,drop,update_data,insert_data
+    from ..config import reader,write
 else:
-    from db import delete, draw,fetch,drop,update_data,insert_data,change_db
+    from db import delete, draw,fetch,drop,update_data,insert_data
+    from config import write,reader
+
+
 
 
 
-# draw the database 
-draw()
 
 print("-"*20,"\n")
 
 app = typer.Typer()
 
 
+
+
 @app.command()
-def config(db):
-    change_db(db)
+def config(group,key,value):
+    write(group,key,value)
+
+if not reader.get("config","db"):
+    print("please set the path of the database [you can add your old database that you've been using with Mikasa tool ] : ")
+    typer.run(config)
+    # draw the database 
+    draw()
+else:
+    # draw the database 
+    draw()
+
 
 @app.command()
 def dropall():
